@@ -4,7 +4,7 @@ use warnings;
 
 package Mail::Box;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.060';
 use base 'Mail::Reporter';
 
 use Mail::Box::Message;
@@ -136,7 +136,7 @@ sub init($)
           ( folder   => $self
           , method   => $args->{lock_type}
           , timeout  => $args->{lock_timeout}
-          , wait     => $args->{lock_wait}
+          , expires  => $args->{lock_wait}
           , file     => ($args->{lockfile} || $args->{lock_file})
           );
 
@@ -146,20 +146,12 @@ sub init($)
 #-------------------------------------------
 
 
-sub create($@) {shift->notImplemented}
-
-#-------------------------------------------
-
-
 sub folderdir(;$)
 {   my $self = shift;
     $self->{MB_folderdir} = shift if @_;
     $self->{MB_folderdir};
 }
 
-#-------------------------------------------
-
-
 sub foundIn($@) { shift->notImplemented }
 
 #-------------------------------------------
@@ -212,13 +204,14 @@ sub organization() { shift->notImplemented }
 #-------------------------------------------
 
 
-sub addMessage($)
+sub addMessage($@)
 {   my $self    = shift;
     my $message = shift or return $self;
+    my %args    = @_;
 
-    confess <<ERROR if $message->can('folder') && $message->folder;
+    confess <<ERROR if $message->can('folder') && defined $message->folder;
 You cannot add a message which is already part of a folder to a new
-one.  Please use moveMessage or copyMessage.
+one.  Please use moveTo or copyTo.
 ERROR
 
     # Force the message into the right folder-type.
@@ -244,6 +237,10 @@ ERROR
     $coerced;
 }
 
+#-------------------------------------------
+
+
+
 sub addMessages(@)
 {   my $self = shift;
     map {$self->addMessage($_)} @_;
@@ -267,14 +264,15 @@ sub copyTo($@)
        :                            (1, 0);
 
     my $delete = $args{delete_copied} || 0;
+    my $share  = $args{share}         || 0;
 
-    $self->_copy_to($to, $select, $flatten, $recurse, $delete);
+    $self->_copy_to($to, $select, $flatten, $recurse, $delete, $share);
 }
 
 # Interface may change without warning.
 sub _copy_to($@)
 {   my ($self, $to, @options) = @_;
-    my ($select, $flatten, $recurse, $delete) = @options;
+    my ($select, $flatten, $recurse, $delete, $share) = @options;
 
     $self->log(ERROR => "Destination folder $to is not writable."),
         return unless $to->writable;
@@ -285,7 +283,8 @@ sub _copy_to($@)
         "Copying ".@select." messages from $self to $to.");
 
     foreach my $msg (@select)
-    {   if($msg->copyTo($to)) { $msg->label(deleted => 1) if $delete }
+    {   if($msg->copyTo($to, share => $share))
+             { $msg->label(deleted => 1) if $delete }
         else { $self->log(ERROR => "Copying failed for one message.") }
     }
 
@@ -339,7 +338,8 @@ sub close(@)
 
     # Inform manager that the folder is closed.
     my $manager = delete $self->{MB_manager};
-    $manager->close($self) if defined $manager && !$args{close_by_manager};
+    $manager->close($self, close_by_self =>1)
+        if defined $manager && !$args{close_by_manager};
 
     my $write;
     for($args{write} || 'MODIFIED')
@@ -364,15 +364,16 @@ Suggestion: \$folder->close(write => 'NEVER')");
                );
 
     $self->locker->unlock;
-    $self->{MB_messages} = [];    # Boom!
+    $self->{MB_messages} = [];                  # Boom!
     $rc;
 }
 
 #-------------------------------------------
 
 
-sub delete()
-{   my $self = shift;
+sub delete(@)
+{   my ($self, %args) = @_;
+    my $recurse = exists $args{recursive} ? $args{recursive} : 1;
 
     # Extra protection: do not remove read-only folders.
     unless($self->writable)
@@ -382,17 +383,15 @@ sub delete()
     }
 
     # Sub-directories need to be removed first.
-    foreach ($self->listSubFolders)
-    {   my $sub = $self->openRelatedFolder(folder => "$self/$_",access => 'rw');
-        next unless defined $sub;
-        $sub->delete;
+    if($recurse)
+    {   foreach ($self->listSubFolders)
+        {   my $sub = $self->openRelatedFolder
+               (folder => "$self/$_", access => 'd', create => 0);
+            defined $sub && $sub->delete(%args);
+        }
     }
 
-    $_->delete foreach $self->messages;
-
-    $self->{MB_remove_empty} = 1;
-    $self->close(write => 'ALWAYS');
-
+    $self->close(write => 'NEVER');
     $self;
 }
 
@@ -404,13 +403,18 @@ sub appendMessages(@) {shift->notImplemented}
 #-------------------------------------------
 
 
-sub writable()  {shift->{MB_access} =~ /w|a/ }
+sub writable()  {shift->{MB_access} =~ /w|a|d/ }
 sub writeable() {shift->writable}  # compatibility [typo]
 sub readable()  {1}  # compatibility
 
 #-------------------------------------------
 
 
+sub access()    {shift->{MB_access}}
+
+#-------------------------------------------
+
+
 sub modified(;$)
 {   my $self = shift;
     return $self->isModified unless @_;   # compat 2.036
@@ -490,6 +494,8 @@ sub messageId($;$)
     }
 
     $self->{MB_msgid}{$msgid} = $message;
+    weaken($self->{MB_msgid}{$msgid});
+    $message;
 }
 
 sub messageID(@) {shift->messageId(@_)} # compatibility
@@ -505,6 +511,10 @@ sub find($)
     {   $msgid = $1;
         $msgid =~ s/\s//gs;
     }
+    else
+    {   # Illegal message-id
+        $msgid =~ s/\s/+/gs;
+    }
 
     $self->scanForMessages(undef, $msgid, 'EVER', 'ALL')
         unless exists $msgids->{$msgid};
@@ -549,6 +559,11 @@ sub messages($;$)
 #-------------------------------------------
 
 
+sub nrMessages(@) { scalar shift->messages(@_) }
+
+#-------------------------------------------
+
+
 sub messageIds()    { map {$_->messageId} shift->messages }
 sub allMessageIds() {shift->messageIds}  # compatibility
 sub allMessageIDs() {shift->messageIds}  # compatibility
@@ -677,14 +692,20 @@ sub openSubFolder($@)
 #-------------------------------------------
 
 
-sub nameOfSubFolder($)
-{   my ($self, $name)= @_;
-    "$self/$name";
+sub nameOfSubFolder($;$)
+{   my ($thing, $name) = (shift, shift);
+    my $parent = @_ ? shift : ref $thing ? $thing->name : undef;
+    defined $parent ? "$parent/$name" : $name;
 }
 
 #-------------------------------------------
 
 
+sub topFolderWithMessages() { 1 }
+
+#-------------------------------------------
+
+
 sub read(@)
 {   my $self = shift;
     $self->{MB_open_time}    = time;
@@ -717,7 +738,7 @@ sub write(@)
 {   my ($self, %args) = @_;
 
     unless($args{force} || $self->writable)
-    {   $self->log(ERROR => "Folder $self is opened read-only.\n");
+    {   $self->log(ERROR => "Folder $self is opened read-only.");
         return;
     }
 
@@ -807,11 +828,19 @@ sub lineSeparator(;$)
 #-------------------------------------------
 
 
-sub coerce($)
-{   my ($self, $message) = @_;
-    $self->{MB_message_type}->coerce($message);
-}
+sub create($@) {shift->notImplemented}
 
+#-------------------------------------------
+
+
+#-------------------------------------------
+
+
+sub coerce($@)
+{   my ($self, $message) = (shift, shift);
+    my $mmtype = $self->{MB_message_type};
+    $message->isa($mmtype) ? $message : $mmtype->coerce($message, @_);
+}
 
 #-------------------------------------------
 
@@ -870,7 +899,7 @@ sub timespan2seconds($)
         :                $1 * 604800;  # week
     }
     else
-    {   $_[0]->log(ERROR => "Invalid timespan '$_' specified.\n");
+    {   $_[0]->log(ERROR => "Invalid timespan '$_' specified.");
         undef;
     }
 }
