@@ -3,13 +3,17 @@ use warnings;
 
 package Mail::Message::Field::Unstructured;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.060';
 use base 'Mail::Message::Field::Full';
 
 
 sub init($)
 {   my ($self, $args) = @_;
 
+    if($args->{body} && ($args->{encoding} || $args->{charset}))
+    {   $args->{body} = $self->encode($args->{body}, %$args);
+    }
+
     $self->SUPER::init($args) or return;
 
     $self->log(WARNING=>"Attributes are not supported for unstructured fields")
@@ -24,4 +28,6 @@ sub init($)
 #------------------------------------------
 
 
+
+
 1;
